==> open-xchange-oauth-provider_7.8.0.orig.tar.bz2: open-xchange-oauth-provider-7.8.0/com.openexchange.oauth.provider.impl/src/com/openexchange/oauth/provider/impl/authcode/AbstractAuthorizationCodeProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.provider.impl.authcode;

import org.apache.commons.lang.RandomStringUtils;
import com.openexchange.exception.OXException;
import com.openexchange.oauth.provider.scope.Scope;
import com.openexchange.server.ServiceLookup;


/**
 * {@link AbstractAuthorizationCodeProvider}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.0
 */
public abstract class AbstractAuthorizationCodeProvider {

    /** The service look-up */
    protected final ServiceLookup services;

    /**
     * Initializes a new {@link AbstractAuthorizationCodeProvider}.
     */
    protected AbstractAuthorizationCodeProvider(ServiceLookup services) {
        super();
        this.services = services;
    }

    public String generateAuthorizationCodeFor(String clientId, String redirectURI, Scope scope, int userId, int contextId) throws OXException {
        String authCode = generateAuthCode(userId, contextId);
        put(new AuthCodeInfo(authCode, clientId, redirectURI, scope, userId, contextId, System.currentTimeMillis()));
        return authCode;
    }

    public abstract AuthCodeInfo remove(String authCode) throws OXException;

    protected abstract void put(AuthCodeInfo authCodeInfo) throws OXException;

    protected String generateAuthCode(int userId, int contextId) {
        return RandomStringUtils.randomAlphabetic(64);
    }


}

==> open-xchange-oauth-provider_7.8.2.orig.tar.bz2: open-xchange-oauth-provider-7.8.2/com.openexchange.oauth.provider.impl/src/com/openexchange/oauth/provider/impl/authcode/AbstractAuthorizationCodeProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.provider.impl.authcode;

import org.apache.commons.lang.RandomStringUtils;
import com.openexchange.exception.OXException;
import com.openexchange.oauth.provider.resourceserver.scope.Scope;


/**
 * {@link AbstractAuthorizationCodeProvider}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.0
 */
public abstract class AbstractAuthorizationCodeProvider {

    /**
     * Initializes a new {@link AbstractAuthorizationCodeProvider}.
     */
    protected AbstractAuthorizationCodeProvider() {
        super();
    }

    public String generateAuthorizationCodeFor(String clientId, String redirectURI, Scope scope, int userId, int contextId) throws OXException {
        String authCode = generateAuthCode(userId, contextId);
        put(new AuthCodeInfo(authCode, clientId, redirectURI, scope, userId, contextId, System.currentTimeMillis()));
        return authCode;
    }

    public abstract AuthCodeInfo remove(String authCode) throws OXException;

    protected abstract void put(AuthCodeInfo authCodeInfo) throws OXException;

    protected String generateAuthCode(int userId, int contextId) {
        return RandomStringUtils.randomAlphabetic(64);
    }


}
